@@ -1,6 +1,6 @@
 /* asn1Coding.c --- program to generate a DER coding of an ASN1 definition.
- * Copyright (C) 2006, 2007, 2008, 2009 Free Software Foundation
- * Copyright (C) 2002 Fabio Fiorina
+ * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010 Free Software
+ * Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -57,7 +57,7 @@ and ASSIGNMENTS file with value assignments.\n\
       printf ("\
 Mandatory arguments to long options are mandatory for short options too.\n\
   -c, --check           checks the syntax only\n\
-  -o, --output FILE     output file\n\
+  -o, --output=FILE     output file\n\
   -h, --help            display this help and exit\n\
   -v, --version         output version information and exit\n");
       emit_bug_reporting_address ();
